/* Sistemas Integrados TECNISA
   Compras e Suprimentos

Nome: LIMPA_ITEMCOLE_MONTAGEM

Descrio:
Limpa os campos que relacionam a itemcole a uma lista de preos na
montagem da lista de preos para que os registros sejam relacionados
a outra lista
*/

CREATE OR REPLACE
PROCEDURE LIMPA_ITEMCOLE_MONTAGEM
   (P_CDFILIAL     IN ITEMCOLE.CDFILIAL%TYPE,
    P_DTINIVALITM  IN ITEMCOLE.DTINIVALITM%TYPE,
    P_DTFINVALITM  IN ITEMCOLE.DTFINVALITM%TYPE,
    P_CDREGIAO     IN VARCHAR2,
    P_TCDREGIAO    IN VARCHAR2,
    P_CDPRODINI    IN PRODUTO.CDARVPROD%TYPE,
    P_CDPRODFIN    IN PRODUTO.CDARVPROD%TYPE,
    P_TPRODUTO     IN VARCHAR2,
    P_CARGCOT      IN VARCHAR2,
    P_CDOPERADOR   IN COLETAPR.CDOPERADOR%TYPE,
    P_COINCIDE     IN VARCHAR2,
    P_NRSEQPRELIST IN PREVLISTA.NRSEQPRELIST%TYPE,
    P_PREENCHETAB  IN VARCHAR2,
    P_ROWSAFFECT  OUT INT
    )
IS
   V_CONT_COMMIT NUMBER := 0;
   V_QTDE_COMMIT NUMBER := 1000;
   V_CDREGIAO    VARCHAR2(120);
   V_TCDREGIAO   CHAR(1);
   V_ERROR       VARCHAR2(2000);
BEGIN
   V_CDREGIAO    := P_CDREGIAO;
   V_TCDREGIAO   := P_TCDREGIAO;
   IF P_PREENCHETAB = 'S' THEN
      IF P_COINCIDE = 'S' THEN
         FOR C_CDREGIAO IN (SELECT CDREGIAO
                              FROM REGIAO
                             WHERE (INSTR(P_CDREGIAO, CDREGIAO) <> 0 OR P_TCDREGIAO = 'T'))
         LOOP
            INSERT INTO ITEMCOLE_TMP (CDFILIALTMP,NRCOLEPRECOTMP,CDMARCATMP,CDREGIAOTMP,CDFORNECEDTMP,CDPRODUTOTMP, NRSEQPRELISTTMP)
            SELECT
               ITEMCOLE.CDFILIAL,
               ITEMCOLE.NRCOLEPRECO,
               ITEMCOLE.CDMARCA,
               ITEMCOLE.CDREGIAO,
               ITEMCOLE.CDFORNECED,
               ITEMCOLE.CDPRODUTO,
               P_NRSEQPRELIST
            FROM ITEMCOLE
            WHERE ITEMCOLE.CDFILIAL    = P_CDFILIAL
              AND ITEMCOLE.DTINIVALITM = P_DTINIVALITM
              AND ITEMCOLE.DTFINVALITM = P_DTFINVALITM
              AND ITEMCOLE.NRSEQPRELIST IS NOT NULL
              AND ITEMCOLE.CDREGIAO = C_CDREGIAO.CDREGIAO
              AND EXISTS (SELECT 1
                          FROM PRODUTO
                          WHERE (PRODUTO.CDARVPROD BETWEEN P_CDPRODINI AND P_CDPRODFIN OR P_TPRODUTO = 'T')
                            AND  ITEMCOLE.CDPRODUTO = PRODUTO.CDPRODUTO)
              AND EXISTS (SELECT 1
                          FROM COLETAPR
                          WHERE (COLETAPR.IDTIPCOLREG IN ('G','W', 'E') OR P_CARGCOT = 'T')
                            AND (COLETAPR.CDOPERADOR  = P_CDOPERADOR)
                            AND (COLETAPR.CDFILIAL    = ITEMCOLE.CDFILIAL)
                            AND (COLETAPR.NRCOLEPRECO = ITEMCOLE.NRCOLEPRECO))
              AND EXISTS (SELECT 1
                          FROM PRODCOMP, PRODUTO PRCOMP, PRODUTO PRODCOT
                          WHERE ITEMCOLE.CDPRODUTO  = PRODCOT.CDPRODUTO
                           AND  PRODCOMP.CDPRODUTO  = PRCOMP.CDPRODUTO
                           AND  PRODCOMP.CDOPERADOR = P_CDOPERADOR
                           AND  PRODCOT.CDARVPROD LIKE PRCOMP.CDARVPROD || '%')
              AND NOT EXISTS (SELECT 1
                              FROM ITMPREVLIST
                              WHERE ITMPREVLIST.CDFILIAL = ITEMCOLE.CDFILIAL
                                AND ITMPREVLIST.NRCOLEPRECO = ITEMCOLE.NRCOLEPRECO
                                AND ITMPREVLIST.CDMARCA = ITEMCOLE.CDMARCA
                                AND ITMPREVLIST.CDREGIAO = ITEMCOLE.CDREGIAO
                                AND ITMPREVLIST.CDFORNECED = ITEMCOLE.CDFORNECED
                                AND ITMPREVLIST.CDPRODUTO = ITEMCOLE.CDPRODUTO
                                AND ITMPREVLIST.NRSEQPRELIST = P_NRSEQPRELIST
                                AND ITMPREVLIST.IDITMLISTJAMONT = 'S');
            P_ROWSAFFECT := SQL%ROWCOUNT;
         END LOOP;
      ELSE
         FOR C_CDREGIAO IN (SELECT CDREGIAO
                              FROM REGIAO
                             WHERE (INSTR(P_CDREGIAO, CDREGIAO) <> 0 OR P_TCDREGIAO = 'T'))
         LOOP
            INSERT INTO ITEMCOLE_TMP (CDFILIALTMP,NRCOLEPRECOTMP,CDMARCATMP,CDREGIAOTMP,CDFORNECEDTMP,CDPRODUTOTMP, NRSEQPRELISTTMP)
            SELECT
               ITEMCOLE.CDFILIAL,
               ITEMCOLE.NRCOLEPRECO,
               ITEMCOLE.CDMARCA,
               ITEMCOLE.CDREGIAO,
               ITEMCOLE.CDFORNECED,
               ITEMCOLE.CDPRODUTO,
               P_NRSEQPRELIST
            FROM ITEMCOLE
            WHERE ITEMCOLE.CDFILIAL     = P_CDFILIAL
              AND ITEMCOLE.DTINIVALITM <= P_DTFINVALITM
              AND ITEMCOLE.DTFINVALITM >= P_DTINIVALITM
              AND ITEMCOLE.NRSEQPRELIST IS NOT NULL
              AND ITEMCOLE.CDREGIAO = C_CDREGIAO.CDREGIAO
              AND EXISTS (SELECT 1
                          FROM PRODUTO
                          WHERE (PRODUTO.CDARVPROD BETWEEN P_CDPRODINI AND P_CDPRODFIN OR P_TPRODUTO = 'T')
                            AND  ITEMCOLE.CDPRODUTO = PRODUTO.CDPRODUTO)
              AND EXISTS (SELECT 1
                          FROM COLETAPR
                          WHERE (COLETAPR.IDTIPCOLREG IN ('G','W', 'E') OR P_CARGCOT = 'T')
                            AND (COLETAPR.CDOPERADOR  = P_CDOPERADOR)
                            AND (COLETAPR.CDFILIAL    = ITEMCOLE.CDFILIAL)
                            AND (COLETAPR.NRCOLEPRECO = ITEMCOLE.NRCOLEPRECO))
              AND EXISTS (SELECT 1
                          FROM PRODCOMP, PRODUTO PRCOMP, PRODUTO PRODCOT
                          WHERE ITEMCOLE.CDPRODUTO  = PRODCOT.CDPRODUTO
                           AND  PRODCOMP.CDPRODUTO  = PRCOMP.CDPRODUTO
                           AND  PRODCOMP.CDOPERADOR = P_CDOPERADOR
                           AND  PRODCOT.CDARVPROD LIKE PRCOMP.CDARVPROD || '%')
              AND NOT EXISTS (SELECT 1
                              FROM ITMPREVLIST
                              WHERE ITMPREVLIST.CDFILIAL = ITEMCOLE.CDFILIAL
                                AND ITMPREVLIST.NRCOLEPRECO = ITEMCOLE.NRCOLEPRECO
                                AND ITMPREVLIST.CDMARCA = ITEMCOLE.CDMARCA
                                AND ITMPREVLIST.CDREGIAO = ITEMCOLE.CDREGIAO
                                AND ITMPREVLIST.CDFORNECED = ITEMCOLE.CDFORNECED
                                AND ITMPREVLIST.CDPRODUTO = ITEMCOLE.CDPRODUTO
                                AND ITMPREVLIST.NRSEQPRELIST = P_NRSEQPRELIST
                                AND ITMPREVLIST.IDITMLISTJAMONT = 'S');
            P_ROWSAFFECT := SQL%ROWCOUNT;
         END LOOP;
      END IF;
   END IF;
   FOR C_ITEMCOLE_TMP IN
      (SELECT
          ITEMCOLE_TMP.CDFILIALTMP CDFILIAL,
          ITEMCOLE_TMP.NRCOLEPRECOTMP NRCOLEPRECO,
          ITEMCOLE_TMP.CDMARCATMP CDMARCA,
          ITEMCOLE_TMP.CDREGIAOTMP CDREGIAO,
          ITEMCOLE_TMP.CDFORNECEDTMP CDFORNECED,
          ITEMCOLE_TMP.CDPRODUTOTMP CDPRODUTO,
          ITEMCOLE_TMP.ROWID
       FROM ITEMCOLE_TMP
       WHERE ITEMCOLE_TMP.CDFILIALTMP = P_CDFILIAL
         AND ITEMCOLE_TMP.NRSEQPRELISTTMP = P_NRSEQPRELIST
         AND ROWNUM <= V_QTDE_COMMIT
       )
   LOOP
      UPDATE ITEMCOLE
      SET IDITMLISPREC = 'N',
          IDPRECALT    = 'N',
          IDITVALDIFLISTA = 'N',
          NRSEQPRELIST = NULL
      WHERE CDFILIAL    = C_ITEMCOLE_TMP.CDFILIAL
        AND NRCOLEPRECO = C_ITEMCOLE_TMP.NRCOLEPRECO
        AND CDMARCA     = C_ITEMCOLE_TMP.CDMARCA
        AND CDREGIAO    = C_ITEMCOLE_TMP.CDREGIAO
        AND CDFORNECED  = C_ITEMCOLE_TMP.CDFORNECED
        AND CDPRODUTO   = C_ITEMCOLE_TMP.CDPRODUTO;

      DELETE FROM ITEMCOLE_TMP
      WHERE ROWID = C_ITEMCOLE_TMP.ROWID;

      V_CONT_COMMIT := V_CONT_COMMIT + 1;
      IF (V_CONT_COMMIT >= V_QTDE_COMMIT) THEN
         EXIT;
      END IF;
   END LOOP;
   IF P_PREENCHETAB = 'S' THEN
      IF P_ROWSAFFECT > V_CONT_COMMIT THEN
         P_ROWSAFFECT := P_ROWSAFFECT - V_CONT_COMMIT;
      ELSE
         P_ROWSAFFECT := 0;
      END IF;
   ELSE
      P_ROWSAFFECT := V_CONT_COMMIT;
   END IF;
END;
/

-- VERSAO --
BEGIN ATUVEROBJ('LIMPA_ITEMCOLE_MONTAGEM','5.05.003'); END;
/

